@@ -20,6 +20,9 @@ sub appropriate_signals {
   if (wantarray) {
     if ($^O eq "MSWin32") {
       return qw(INT QUIT);
+    } elsif ($^O eq 'freebsd') {
+      # are USR1, USR2 not available on freebsd sometimes?
+      return qw(USR1 USR2);
     } else {
       return qw(USR1 USR2);
     }
